@@ -1,6 +1,6 @@
 /* gcompris - clockgame.c
  *
- * Time-stamp: <2001/05/24 22:49:42 bruno>
+ * Time-stamp: <2001/09/12 23:44:20 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -50,9 +50,10 @@ static Time timeToFind, currentTime;
 
 static void start_board (GcomprisBoard *agcomprisBoard);
 static void pause_board (gboolean pause);
-static void end_board ();
+static void end_board (void);
 static gboolean is_our_board (GcomprisBoard *gcomprisBoard);
 static void set_level (guint level);
+static void process_ok(void);
 
 static GnomeCanvasItem *clockgame_create_item(GnomeCanvasGroup *parent);
 static void clockgame_destroy_item(GnomeCanvasItem *item);
@@ -60,7 +61,6 @@ static void clockgame_destroy_all_items(void);
 static void get_random_hour(Time *time);
 static void clockgame_next_level(void);
 static gint item_event(GnomeCanvasItem *item, GdkEvent *event, gpointer data);
-static void process_ok();
 static void display_hour(guint hour);
 static void display_minute(guint minute);
 static void display_second(guint second);
@@ -133,6 +133,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       gcomprisBoard->maxlevel=6;
       gcomprisBoard->sublevel=0;
       gcomprisBoard->number_of_sublevel=3; /* Go to next level after this number of 'play' */
+      gcompris_bar_set(GCOMPRIS_BAR_LEVEL|GCOMPRIS_BAR_OK);
       gcompris_bar_set_timer(0);
 
       clockgame_next_level();
