@@ -1,6 +1,6 @@
 /* gcompris - menu.c
  *
- * Time-stamp: <2001/05/24 22:48:23 bruno>
+ * Time-stamp: <2001/08/30 23:33:28 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -65,7 +65,7 @@ static double current_y = 0.0;
 static GList		*boardlist;	/* List of Board */
 
 /* Information items */
-static GnomeCanvasItem *boardname_item, *description_item;
+static GnomeCanvasItem *boardname_item, *description_item, *author_item;
 
 /* Description of this plugin */
 BoardPlugin menu_bp =
@@ -133,6 +133,11 @@ static void menu_start (GcomprisBoard *agcomprisBoard)
       
       create_info_area(gnome_canvas_root(gcomprisBoard->canvas));
       
+      /* set initial values for this level */
+      gcomprisBoard->level = 1;
+      gcomprisBoard->maxlevel=1;
+      gcompris_bar_set(0);
+
       menu_pause(FALSE);
 
     }
@@ -272,6 +277,9 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, MenuItem *menuitem)
       gnome_canvas_item_set (description_item,
 			     "text",  menuitem->board->description,
 			     NULL);
+      gnome_canvas_item_set (author_item,
+			     "text",  menuitem->board->author,
+			     NULL);
 
       break;
     case GDK_LEAVE_NOTIFY:
@@ -283,6 +291,10 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, MenuItem *menuitem)
 			     "text",  " ",
 			     NULL);
 
+      gnome_canvas_item_set (author_item,
+			     "text",  " ",
+			     NULL);
+
       break;
     case GDK_BUTTON_PRESS:
       gcompris_play_sound (SOUNDLISTFILE, "gobble");
@@ -314,12 +326,15 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, MenuItem *menuitem)
 
 static void create_info_area(GnomeCanvasGroup *parent)
 {
-  GnomeCanvasItem *rootitem, *rectitem;
-  GdkFont *gdk_font, *gdk_font_small;
+  GnomeCanvasItem *rootitem;
+  GdkFont *gdk_font, *gdk_font_small, *gdk_font_big;
+  gint x = (double)gcomprisBoard->width/2;
+  gint y = 400;
 
   /* Load a gdk font */
   gdk_font = gdk_font_load ("-adobe-times-medium-r-normal--*-180-*-*-*-*-*-*");
   gdk_font_small = gdk_font_load ("-adobe-times-medium-r-normal--*-120-*-*-*-*-*-*");
+  gdk_font_big = gdk_font_load ("-adobe-times-medium-r-normal--*-240-*-*-*-*-*-*");
 
   rootitem = \
     gnome_canvas_item_new (parent,
@@ -328,39 +343,38 @@ static void create_info_area(GnomeCanvasGroup *parent)
 			   "y", (double)(gcomprisBoard->height*13)/20,
 			   NULL);
 
-  rectitem = \
-    gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
-			   gnome_canvas_rect_get_type (),
-			   "x1", (double)-gcomprisBoard->width/2+20,
-			   "y1", (double)0,
-			   "x2", (double)gcomprisBoard->width/2-20,
-			   "y2", (double)(gcomprisBoard->height*2)/10,
-			   "fill_color", "black",
-			   "outline_color", "blue",
-			   "width_units", (double)5,
-			   NULL);
-
-
   boardname_item = \
-    gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
+    gnome_canvas_item_new (parent,
 			   gnome_canvas_text_get_type (),
 			   "text", "",
-			   "font_gdk", gdk_font,
-			   "x", (double) 0,
-			   "y", (double) 25,
+			   "font_gdk", gdk_font_big,
+			   "x", (double) x,
+			   "y", (double) y,
 			   "anchor", GTK_ANCHOR_CENTER,
-			   "fill_color", "green",
+			   "fill_color", "white",
 			   NULL);
 
   description_item = \
-    gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
+    gnome_canvas_item_new (parent,
 			   gnome_canvas_text_get_type (),
 			   "text", "",
 			   "font_gdk", gdk_font_small,
-			   "x", (double) 0,
-			   "y", (double) 60,
+			   "x", (double) x,
+			   "y", (double) y + 40,
 			   "anchor", GTK_ANCHOR_NORTH,
-			   "fill_color", "lightgreen",
+			   "fill_color", "white",
+			   "justification", GTK_JUSTIFY_CENTER,
+			   NULL);
+
+  author_item = \
+    gnome_canvas_item_new (parent,
+			   gnome_canvas_text_get_type (),
+			   "text", "",
+			   "font_gdk", gdk_font_small,
+			   "x", (double) x,
+			   "y", (double) y + 90,
+			   "anchor", GTK_ANCHOR_NORTH,
+			   "fill_color", "white",
 			   "justification", GTK_JUSTIFY_CENTER,
 			   NULL);
 }
