@@ -1,6 +1,6 @@
 /* gcompris - planegame.c
  *
- * Time-stamp: <2001/07/01 01:30:44 bruno>
+ * Time-stamp: <2001/09/12 23:43:33 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -49,7 +49,7 @@ static char *pixmapsdir = "gcompris/misc/";
 
 static void start_board (GcomprisBoard *agcomprisBoard);
 static void pause_board (gboolean pause);
-static void end_board ();
+static void end_board (void);
 static gboolean is_our_board (GcomprisBoard *gcomprisBoard);
 static void set_level (guint level);
 gint key_press(guint keyval);
@@ -147,6 +147,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       /* set initial values for this level */
       gcomprisBoard->level = 1;
       gcomprisBoard->maxlevel = 6;
+      gcompris_bar_set(GCOMPRIS_BAR_LEVEL);
 
       planegame_next_level();
 
@@ -301,7 +302,7 @@ static void planegame_next_level()
   planegame_destroy_all_items();
 
   /* Try the next level */
-  speed=10+(40/(gcomprisBoard->level));
+  speed=100+(40/(gcomprisBoard->level));
   fallSpeed=7000-gcomprisBoard->level*200;
   gcomprisBoard->number_of_sublevel=10;
   /* Make the images tend to 0.5 ratio */
@@ -313,7 +314,7 @@ static void planegame_next_level()
   /* Setup and Display the plane */
   planespeed_y = 0;
   planespeed_x = 0;
-  str = g_strdup_printf("%s%s", pixmapsdir, "plane.png");
+  str = g_strdup_printf("%s%s", pixmapsdir, "tuxplane.png");
   pixmap = gcompris_load_pixmap(str);
   plane_x = 50;
   plane_y = 300;
@@ -322,8 +323,10 @@ static void planegame_next_level()
 				     "pixbuf", pixmap, 
 				     "x", (double) plane_x,
 				     "y", (double) plane_y,
-				     "width", (double) gdk_pixbuf_get_width(pixmap)*imageZoom,
-				     "height", (double) gdk_pixbuf_get_height(pixmap)*imageZoom,
+				     "width", (double) gdk_pixbuf_get_width(pixmap)*imageZoom*0.7,
+				     "height", (double) gdk_pixbuf_get_height(pixmap)*imageZoom*0.7,
+				     "width_set", TRUE, 
+				     "height_set", TRUE,
 				     NULL);
   gdk_pixbuf_unref(pixmap);
 
