@@ -1,6 +1,6 @@
 /* gcompris - shapegame.c
  *
- * Time-stamp: <2001/06/26 23:48:39 bruno>
+ * Time-stamp: <2001/09/12 23:45:42 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -40,7 +40,8 @@ typedef enum
   SHAPE_TARGET		= 1 << 0,
   SHAPE_DUMMY_TARGET	= 1 << 1,
   SHAPE_ICON		= 1 << 2,
-  SHAPE_BACKGROUND	= 1 << 3
+  SHAPE_BACKGROUND	= 1 << 3,
+  SHAPE_COLORLIST	= 1 << 4
 } ShapeType;
 
 /* Let's define the structure for a single shape */
@@ -48,6 +49,7 @@ typedef struct _Shape Shape;
 struct _Shape {
   char  *name;			/* name of the shape */
   char  *pixmapfile;		/* relative pixmap file name of the shape */
+  GnomeCanvasPoints* points;    /* OR list of points for this shape */
   char  *targetfile;		/* OPTIONAL relative pixmap file name of the target shape, by default 
 				   a red point is displayed */
   double x;			/* x coordinate */
@@ -66,21 +68,36 @@ struct _Shape {
   gboolean found;		/* The user found this item */
 };
 
+gchar *colorlist [] = 
+  {
+    "black",
+    "brown",
+    "red",
+    "orange",
+    "yellow",
+    "green",
+    "blue",
+    "purple",
+    "grey",
+    "white",
+  };
+
 /* This is the list of shape for the current game */
 static GList *shape_list = NULL;
 
 /* Hash table of all the shapes in the list of shapes (one by different pixmap plus icon list) */
 static GHashTable *shapelist_table = NULL;
-static gint SHAPE_BOX_WIDTH_RATIO = 14;
+static gint SHAPE_BOX_WIDTH_RATIO = 18;
 
 static GnomeCanvasItem *shape_root_item;
 static GnomeCanvasItem *shape_list_root_item;
 
 static void start_board (GcomprisBoard *agcomprisBoard);
 static void pause_board (gboolean pause);
-static void end_board ();
+static void end_board (void);
 static gboolean is_our_board (GcomprisBoard *gcomprisBoard);
 static void set_level (guint level);
+static void process_ok(void);
 
 static GnomeCanvasItem *shapegame_init_canvas(GnomeCanvasGroup *parent);
 static void shapegame_destroy_all_items(void);
@@ -89,10 +106,10 @@ static void shapegame_next_level(void);
 static gboolean read_xml_file(char *fname);
 static gboolean write_xml_file(char *fname);
 static Shape *find_closest_shape(double x, double y, double limit);
-static Shape *create_shape(ShapeType type, char *name, char *pixmapfile,  char *targetfile,
-			   double x, double y, double l, double h, double zoomx, 
+static Shape *create_shape(ShapeType type, char *name, char *pixmapfile,  GnomeCanvasPoints* points,
+			   char *targetfile, double x, double y, double l, double h, double zoomx, 
 			   double zoomy, guint position);
-static void process_ok();
+static void display_color_selector(GnomeCanvasGroup *parent);
 
 /* Description of this plugin */
 BoardPlugin menu_bp =
@@ -100,7 +117,7 @@ BoardPlugin menu_bp =
    NULL,
    NULL,
    N_("Make the puzzle"),
-   N_("Drag and Drop the items to rebuild the original paintings"),
+   N_("Drag and Drop the items to rebuild the object"),
    "Bruno Coudoin <bruno.coudoin@free.fr>",
    NULL,
    NULL,
@@ -148,12 +165,12 @@ static void start_board (GcomprisBoard *agcomprisBoard)
     {
       gcomprisBoard=agcomprisBoard;
 
-      gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), "gcompris/gcompris-bg.jpg");
-
+      gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), "gcompris/gcompris-shapebg.jpg");
 
       /* set initial values for this level */
       gcomprisBoard->level = 1;
       gcomprisBoard->maxlevel=6;
+      gcompris_bar_set(GCOMPRIS_BAR_LEVEL|GCOMPRIS_BAR_OK);
 
       gcomprisBoard->number_of_sublevel=6;
       gcompris_bar_set_maxtimer(gcomprisBoard->number_of_sublevel);
@@ -249,6 +266,7 @@ static void shapegame_next_level()
   filename = g_strdup_printf("%s/%s/board%d_%d.xml",  
 			     PACKAGE_DATA_DIR, gcomprisBoard->boarddir, 
 			     gcomprisBoard->level, gcomprisBoard->sublevel);
+
   if(!g_file_exists(filename)) 
     {
       /* Try the next level */
@@ -298,6 +316,8 @@ static void destroy_shape (Shape *shape)
 {
   g_free(shape->name);
   g_free(shape->pixmapfile);
+  g_free(shape->targetfile);
+  gnome_canvas_points_unref(shape->points);
   g_free(shape);
 }
 
@@ -327,7 +347,7 @@ static void shapegame_destroy_all_items()
 
 static GnomeCanvasItem *shapegame_init_canvas(GnomeCanvasGroup *parent)
 {
-  GnomeCanvasItem *item;
+  GnomeCanvasItem *item = NULL;
 
 
   shape_list_root_item = \
@@ -338,19 +358,6 @@ static GnomeCanvasItem *shapegame_init_canvas(GnomeCanvasGroup *parent)
 			   NULL);
   item_list = g_list_append (item_list, shape_list_root_item);
 
-  /* Create the background box */
-  item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(shape_list_root_item),
-				gnome_canvas_rect_get_type (),
-				"x1", (double)-gcomprisBoard->width/SHAPE_BOX_WIDTH_RATIO,
-				"y1", (double)0,
-				"x2", (double)gcomprisBoard->width/SHAPE_BOX_WIDTH_RATIO,
-				"y2", (double)gcomprisBoard->height-2,
-				"fill_color_rgba", 0x5f9ea080,
-				"outline_color", "cyan",
-				"width_units", (double)1,
-				NULL);
-  item_list = g_list_append (item_list, item);
-
   shape_root_item = \
     gnome_canvas_item_new (parent,
 			   gnome_canvas_group_get_type (),
@@ -422,7 +429,7 @@ static void
 add_shape_to_list_of_shapes(Shape *shape)
 {
   GnomeCanvasItem *item;
-  gint MAX_NUMBER_OF_SHAPES = 6;
+  gint MAX_NUMBER_OF_SHAPES = 8;
   double SHAPE_ELEM_NUMBER_IN_HEIGHT = (double)gcomprisBoard->height/MAX_NUMBER_OF_SHAPES;
 
   if(!shapelist_table)
@@ -440,45 +447,48 @@ add_shape_to_list_of_shapes(Shape *shape)
       /* So this shape is not yet in, let's put it in now */
       g_hash_table_insert (shapelist_table, shape->pixmapfile, shape);
 
-      pixmap = gcompris_load_pixmap(shape->pixmapfile);
-      if(pixmap)
+      if(strcmp(shape->pixmapfile, UNDEFINED)!=0)
 	{
-	  double w, h;
-	  guint SHAPE_SIZE = SHAPE_ELEM_NUMBER_IN_HEIGHT - 20;
-	  Shape *icon_shape;
-
-	  /* Calc a zoom factor so that the shape will fit in the shapelist
-	     whatever its current size */
-	  w = SHAPE_SIZE;
-	  h = gdk_pixbuf_get_height(pixmap) * ( w / gdk_pixbuf_get_width(pixmap));
-
-	  if(h > SHAPE_SIZE)
+	  pixmap = gcompris_load_pixmap(shape->pixmapfile);
+	  if(pixmap)
 	    {
-	      h = SHAPE_SIZE;
-	      w = gdk_pixbuf_get_width(pixmap) * ( h / gdk_pixbuf_get_height(pixmap));
+	      double w, h;
+	      guint SHAPE_SIZE = SHAPE_ELEM_NUMBER_IN_HEIGHT - 20;
+	      Shape *icon_shape;
+	      
+	      /* Calc a zoom factor so that the shape will fit in the shapelist
+		 whatever its current size */
+	      w = SHAPE_SIZE;
+	      h = gdk_pixbuf_get_height(pixmap) * ( w / gdk_pixbuf_get_width(pixmap));
+	      
+	      if(h > SHAPE_SIZE)
+		{
+		  h = SHAPE_SIZE;
+		  w = gdk_pixbuf_get_width(pixmap) * ( h / gdk_pixbuf_get_height(pixmap));
+		}
+	      
+	      item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(shape_list_root_item),
+					    gnome_canvas_pixbuf_get_type (),
+					    "pixbuf", pixmap, 
+					    "x", (double)-w/2,
+					    "y", (double)y_offset-h/2,
+					    "width", (double) w,
+					    "height", (double) h,
+					    "width_set", TRUE, 
+					    "height_set", TRUE,
+					    NULL);
+	      gdk_pixbuf_unref(pixmap);
+	      
+	      icon_shape = create_shape(SHAPE_ICON, shape->name, shape->pixmapfile, shape->points, shape->targetfile,
+					(double)0, (double)y_offset,
+					(double)w, (double)h, 
+					(double)1, (double)1,
+					0);
+	      icon_shape->item = item;
+	      
+	      setup_item(item, icon_shape);
+	      item_list = g_list_append (item_list, item);
 	    }
-
-	  item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(shape_list_root_item),
-					gnome_canvas_pixbuf_get_type (),
-					"pixbuf", pixmap, 
-					"x", (double)-w/2,
-					"y", (double)y_offset-h/2,
-					"width", (double) w,
-					"height", (double) h,
-					"width_set", TRUE, 
-					"height_set", TRUE,
-					NULL);
-	  gdk_pixbuf_unref(pixmap);
-
-	  icon_shape = create_shape(SHAPE_ICON, shape->name, shape->pixmapfile, shape->targetfile, 
-				    (double)0, (double)y_offset,
-				    (double)w, (double)h, 
-				    (double)1, (double)1,
-				    0);
-	  icon_shape->item = item;
-
-	  setup_item(item, icon_shape);
-	  item_list = g_list_append (item_list, item);
 	}
     }
 }
@@ -546,6 +556,49 @@ static void shape_goes_back_to_list(Shape *shape, GnomeCanvasItem *item)
     }
 }
 
+static void display_color_selector(GnomeCanvasGroup *parent)
+{
+  GdkPixbuf *pixmap;
+  GnomeCanvasItem *item = NULL;
+  gint x  = 0;
+  gint y  = 0;
+  gint x1 = 0;
+  gint c  = 0;
+
+  pixmap = gcompris_load_pixmap("draw/color-selector.jpg");
+  if(pixmap)
+    {
+      x = (gcomprisBoard->width
+	   - gcomprisBoard->width/SHAPE_BOX_WIDTH_RATIO*2
+	   - gdk_pixbuf_get_width(pixmap))/2 
+	+ gcomprisBoard->width/SHAPE_BOX_WIDTH_RATIO;
+      
+      y = gcomprisBoard->height - gdk_pixbuf_get_height(pixmap) - 5;
+
+      item = gnome_canvas_item_new (parent,
+				    gnome_canvas_pixbuf_get_type (),
+				    "pixbuf", pixmap, 
+				    "x", (double) x,
+				    "y", (double) y,
+				    NULL);
+      gdk_pixbuf_unref(pixmap);
+    }
+
+  
+  for(x1=x+26; x1<(x+26)+55*10; x1+=55)
+    {
+      item = gnome_canvas_item_new (parent,
+			     gnome_canvas_rect_get_type (),
+			     "x1", (double) x1,
+			     "y1", (double) y + 8,
+			     "x2", (double) x1 + 50,
+			     "y2", (double) y + gdk_pixbuf_get_height(pixmap) - 8,
+			     "fill_color", colorlist[c],
+			     NULL);
+      c++;
+    }
+}
+
 static gint
 item_event(GnomeCanvasItem *item, GdkEvent *event, Shape *shape)
 {
@@ -690,8 +743,10 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, Shape *shape)
 		   item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(shape_root_item),
 						 gnome_canvas_pixbuf_get_type (),
 						 "pixbuf", pixmap, 
-						 "x", (double)targetshape->x - (gdk_pixbuf_get_width(pixmap) * targetshape->zoomx)/2,
-						 "y", (double)targetshape->y - (gdk_pixbuf_get_height(pixmap) * targetshape->zoomy/2),
+						 "x", (double)targetshape->x - (gdk_pixbuf_get_width(pixmap) 
+										* targetshape->zoomx)/2,
+						 "y", (double)targetshape->y - (gdk_pixbuf_get_height(pixmap) 
+										* targetshape->zoomy/2),
 						 "width", (double) gdk_pixbuf_get_width(pixmap) * targetshape->zoomx,
 						 "height", (double) gdk_pixbuf_get_height(pixmap) * targetshape->zoomy,
 						 "width_set", TRUE, 
@@ -763,81 +818,105 @@ add_shape_to_canvas(Shape *shape)
 {
   GdkPixbuf *pixmap;
   GdkPixbuf *targetpixmap;
-  GnomeCanvasItem *item;
+  GnomeCanvasItem *item = NULL;
 
   /* checking of preconditions, this is usefull for tracking down bugs,
      but you should not count on these always being compiled in */
   g_return_if_fail(shape != NULL);
-	
-  pixmap = gcompris_load_pixmap(shape->pixmapfile);
-  if(pixmap)
-    {	
-      if(shape->type==SHAPE_TARGET)
+
+  if(shape->type==SHAPE_TARGET)
+    {
+      if(strcmp(shape->targetfile, UNDEFINED)!=0)
 	{
-	  if(strcmp(shape->targetfile, UNDEFINED)!=0)
-	    {
-	      targetpixmap = gcompris_load_pixmap(shape->targetfile);
+	  targetpixmap = gcompris_load_pixmap(shape->targetfile);
+	  item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(shape_root_item),
+					gnome_canvas_pixbuf_get_type (),
+					"pixbuf", targetpixmap, 
+					"x", (double)shape->x - 
+					(gdk_pixbuf_get_width(targetpixmap) * shape->zoomx)/2,
+					"y", (double)shape->y -
+					(gdk_pixbuf_get_height(targetpixmap) * shape->zoomy)/2,
+					"width", (double) gdk_pixbuf_get_width(targetpixmap) 
+					* shape->zoomx,
+					"height", (double) gdk_pixbuf_get_height(targetpixmap) 
+					* shape->zoomy,
+					"width_set", TRUE, 
+					"height_set", TRUE,
+					NULL);
+	  gdk_pixbuf_unref(targetpixmap);
+	} 
+      else
+	{
+	  /* Display a point to highlight the target location of this shape */
+	  item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(shape_root_item),
+					gnome_canvas_ellipse_get_type(),
+					"x1", (double)shape->x-2.5,
+					"y1", (double)shape->y-2.5,
+					"x2", (double)shape->x+2.5,
+					"y2", (double)shape->y+2.5,
+					"fill_color_rgba", 0xEf000080,
+					"outline_color", "black",
+					"width_pixels", 0,
+					NULL);
+	}
+      gnome_canvas_item_lower_to_bottom(item);
+      item_list = g_list_append (item_list, item);
+    }
+  
+  if(shape->points!=NULL)
+    {
+      printf("it's a point \n");
+      item = gnome_canvas_item_new(GNOME_CANVAS_GROUP(shape_root_item),
+				   gnome_canvas_polygon_get_type (),
+				   "points", shape->points,
+				   "fill_color", "grey",
+				   "outline_color", "black",
+				   "width_units", 1.0,
+				   NULL);
+    }
+  else
+    {
+      printf("it's an image ? shape->pixmapfile=%s\n", shape->pixmapfile);
+      if(strcmp(shape->pixmapfile, UNDEFINED)!=0)
+	{
+	  printf("it's an image \n");
+	  pixmap = gcompris_load_pixmap(shape->pixmapfile);
+	  if(pixmap)
+	    {	
+	      /* Display the shape itself but hide it until the user puts the right shape on it */
+	      /* I have to do it this way for the positionning (lower/raise) complexity          */
 	      item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(shape_root_item),
 					    gnome_canvas_pixbuf_get_type (),
-					    "pixbuf", targetpixmap, 
-					    "x", (double)shape->x-(gdk_pixbuf_get_width(targetpixmap) * shape->zoomx)/2,
-					    "y", (double)shape->y-(gdk_pixbuf_get_height(targetpixmap) * shape->zoomy)/2,
-					    "width", (double) gdk_pixbuf_get_width(targetpixmap) * shape->zoomx,
-					    "height", (double) gdk_pixbuf_get_height(targetpixmap) * shape->zoomy,
+					    "pixbuf", pixmap, 
+					    "x", (double)shape->x-(gdk_pixbuf_get_width(pixmap) * shape->zoomx)/2,
+					    "y", (double)shape->y-(gdk_pixbuf_get_height(pixmap) * shape->zoomy)/2,
+					    "width", (double) gdk_pixbuf_get_width(pixmap) * shape->zoomx,
+					    "height", (double) gdk_pixbuf_get_height(pixmap) * shape->zoomy,
 					    "width_set", TRUE, 
 					    "height_set", TRUE,
 					    NULL);
-	      gdk_pixbuf_unref(targetpixmap);
-	    } 
-	  else
-	    {
-	      /* Display a point to highlight the target location of this shape */
-	      item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(shape_root_item),
-					    gnome_canvas_ellipse_get_type(),
-					    "x1", (double)shape->x-2.5,
-					    "y1", (double)shape->y-2.5,
-					    "x2", (double)shape->x+2.5,
-					    "y2", (double)shape->y+2.5,
-					    "fill_color_rgba", 0xEf000080,
-					    "outline_color", "black",
-					    "width_pixels", 0,
-					    NULL);
+	      gdk_pixbuf_unref(pixmap);
 	    }
-	  gnome_canvas_item_lower_to_bottom(item);
-	  item_list = g_list_append (item_list, item);
 	}
-
-      /* Display the shape itself but hide it until the user puts the right shape on it */
-      /* I have to do it this way for the positionning (lower/raise) complexity          */
-      item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(shape_root_item),
-				    gnome_canvas_pixbuf_get_type (),
-				    "pixbuf", pixmap, 
-				    "x", (double)shape->x-(gdk_pixbuf_get_width(pixmap) * shape->zoomx)/2,
-				    "y", (double)shape->y-(gdk_pixbuf_get_height(pixmap) * shape->zoomy)/2,
-				    "width", (double) gdk_pixbuf_get_width(pixmap) * shape->zoomx,
-				    "height", (double) gdk_pixbuf_get_height(pixmap) * shape->zoomy,
-				    "width_set", TRUE, 
-				    "height_set", TRUE,
-				    NULL);
-      gdk_pixbuf_unref(pixmap);
-
-      if(shape->position>=1)
-	gnome_canvas_item_lower(item, ABS(shape->position)); 
-
-      /* Associate this item to this shape */
-      shape->item = item;
-
-      if(shape->type==SHAPE_TARGET || shape->type==SHAPE_DUMMY_TARGET)
-	{
-	  setup_item(item, shape);
-	  item_list = g_list_append (item_list, item);
-
-	  gnome_canvas_item_hide(item);
-	  add_shape_to_list_of_shapes(shape);
-	}
-      else if(shape->type==SHAPE_BACKGROUND)
-	gnome_canvas_item_lower_to_bottom(item);
     }
+
+  if(shape->position>=1)
+    gnome_canvas_item_lower(item, ABS(shape->position)); 
+  
+  /* Associate this item to this shape */
+  shape->item = item;
+
+  if(shape->type==SHAPE_TARGET || shape->type==SHAPE_DUMMY_TARGET)
+    {
+      setup_item(item, shape);
+      item_list = g_list_append (item_list, item);
+
+      gnome_canvas_item_hide(item);
+      add_shape_to_list_of_shapes(shape);
+    }
+  else if(shape->type==SHAPE_BACKGROUND)
+    gnome_canvas_item_lower_to_bottom(item);
+
 }
 
 void create_title(char *name, double x, double y, char *justification)
@@ -864,7 +943,8 @@ void create_title(char *name, double x, double y, char *justification)
 }
 
 static Shape *
-create_shape(ShapeType type, char *name, char *pixmapfile, char *targetfile, double x, double y, 
+create_shape(ShapeType type, char *name, char *pixmapfile, GnomeCanvasPoints* points,
+	     char *targetfile, double x, double y, 
 	     double w, double h, double zoomx, 
 	     double zoomy, guint position)
 {
@@ -875,6 +955,7 @@ create_shape(ShapeType type, char *name, char *pixmapfile, char *targetfile, dou
   
   shape->name = g_strdup(name);
   shape->pixmapfile = g_strdup(pixmapfile);
+  shape->points = points;
   shape->targetfile = g_strdup(targetfile);
   shape->x = x;
   shape->y = y;
@@ -900,8 +981,11 @@ create_shape(ShapeType type, char *name, char *pixmapfile, char *targetfile, dou
 static void
 add_xml_shape_to_data(xmlNodePtr xmlnode, GNode * child)
 {
-  char *name, *pixmapfile, *targetfile, *cx, *cy, *czoomx, *czoomy, *cposition, *ctype, *justification;
+  char *name, *pixmapfile, *targetfile, *cx, *cy, *cd, *czoomx, *czoomy, *cposition, *ctype, *justification;
   double x, y, zoomx, zoomy;
+  GnomeCanvasPoints* points = NULL;
+  gchar **d;
+  gint i, j;
   guint position;
   ShapeType type = SHAPE_TARGET;
   Shape *shape;
@@ -911,7 +995,9 @@ add_xml_shape_to_data(xmlNodePtr xmlnode, GNode * child)
      /* or if the name is not "Shape" */
      (g_strcasecmp(xmlnode->name,"Shape")!=0 &&
      /* or if the name is not "Title" */
-      g_strcasecmp(xmlnode->name,"Title")!=0)
+      g_strcasecmp(xmlnode->name,"Title")!=0 &&
+     /* or if the name is not "Option" */
+      g_strcasecmp(xmlnode->name,"Option")!=0)
      )
     return;
   
@@ -926,6 +1012,35 @@ add_xml_shape_to_data(xmlNodePtr xmlnode, GNode * child)
   /* if unspecified, make it UNDEFINED */
   if(!targetfile) targetfile = UNDEFINED;
 
+  /*********************************/
+  /* get the points for a polygone */
+  /* The list of points is similar to the one define in the SVG standard */
+  /* FIXME : The implementation is incomplete, a point still needs to be added
+     to shapelist and add management for it's x/y coordinates */
+  cd = xmlGetProp(xmlnode,"points");
+  if(!cd) 
+    {
+      cd = "";
+    }
+  else
+    {
+      d = g_strsplit(cd, " ", 64);
+
+      j=0;
+      while(d[j]!=NULL) 
+	{
+	  j++;
+	}
+
+      points = gnome_canvas_points_new(j/2);
+
+      for(i=0; i<j; i++)
+	{
+	  points->coords[i] = atof(d[i]);
+	}
+      g_strfreev(d);
+    }
+
   /* get the X coord of the shape */
   cx = xmlGetProp(xmlnode,"x");
   if(!cx) cx = "100";
@@ -960,6 +1075,8 @@ add_xml_shape_to_data(xmlNodePtr xmlnode, GNode * child)
     type = SHAPE_DUMMY_TARGET;
   else if (g_strcasecmp(ctype,"SHAPE_BACKGROUND")==0)
     type = SHAPE_BACKGROUND;
+  else if (g_strcasecmp(ctype,"SHAPE_COLORLIST")==0)
+    type = SHAPE_COLORLIST;
 
   /* get the JUSTIFICATION of the Title */
   justification = xmlGetProp(xmlnode,"justification");
@@ -970,7 +1087,7 @@ add_xml_shape_to_data(xmlNodePtr xmlnode, GNode * child)
     {
       /* add the shape to the database */
       /* WARNING : I do not initialize the width and height since I don't need them */
-      shape = create_shape(type, name, pixmapfile, targetfile, x, y, 
+      shape = create_shape(type, name, pixmapfile, points, targetfile, x, y, 
 			   (double)0, (double)0,
 			   zoomx, zoomy, position);
       add_shape_to_canvas(shape);
@@ -979,6 +1096,10 @@ add_xml_shape_to_data(xmlNodePtr xmlnode, GNode * child)
     {
       create_title(name, x, y, justification);
     }
+  else if (g_strcasecmp(xmlnode->name,"Option")==0)
+    {
+      display_color_selector(GNOME_CANVAS_GROUP(shape_root_item));
+    }
   
 }
 
@@ -1016,6 +1137,7 @@ read_xml_file(char *fname)
       g_warning(_("Couldn't find file %s !"), fname);
       return FALSE;
     }
+      g_warning(_("find file %s !"), fname);
 
   /* parse the new file and put the result into newdoc */
   doc = xmlParseFile(fname);
