@@ -1,6 +1,6 @@
 /* gcompris - smallnumbers.c
  *
- * Time-stamp: <2001/05/14 00:55:08 bruno>
+ * Time-stamp: <2001/09/12 23:46:04 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  * 
@@ -31,14 +31,14 @@ static GcomprisBoard *gcomprisBoard = NULL;
 static gint dummy_id = 0;
 static gint drop_items_id = 0;
 
-static char *numbers = "123456";
+static char *numbers = "123456789";
 
 /* Hash table of all displayed letters  */
 static GHashTable *letters_table= NULL;
 
 static void start_board (GcomprisBoard *agcomprisBoard);
 static void pause_board (gboolean pause);
-static void end_board ();
+static void end_board (void);
 static gboolean is_our_board (GcomprisBoard *gcomprisBoard);
 static void set_level (guint level);
 gint key_press(guint keyval);
@@ -67,7 +67,7 @@ BoardPlugin menu_bp =
    NULL,
    NULL,
    N_("Numbers With Dices"),
-   N_("Type the keyboard number 1 to 6 before the dices reach the ground"),
+   N_("Type the keyboard number 1 to 9 before the dices reach the ground"),
    "Bruno Coudoin <bruno.coudoin@free.fr>",
    NULL,
    NULL,
@@ -140,6 +140,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 
       gcomprisBoard->level = 1;
       gcomprisBoard->maxlevel = 6;
+      gcompris_bar_set(GCOMPRIS_BAR_LEVEL);
 
       smallnumbers_next_level();
 
@@ -289,7 +290,7 @@ static void smallnumbers_next_level()
   smallnumbers_destroy_all_items();
 
   /* Try the next level */
-  speed=10+(40/gcomprisBoard->level);
+  speed=100+(40/gcomprisBoard->level);
   fallSpeed=5000-gcomprisBoard->level*200;
   gcomprisBoard->number_of_sublevel=10;
   imageZoom=0.9+(0.5/gcomprisBoard->level);
@@ -396,10 +397,13 @@ static GnomeCanvasItem *smallnumbers_create_item(GnomeCanvasGroup *parent)
 
   /* Beware, since we put the letters in a hash table, we do not allow the same
      letter to be displayed two times */
-  do {
-    i=rand()%strlen(numbers);
-    sprintf(lettersItem, "%c", numbers[i]);
-  } while(item_find_by_title(lettersItem)!=NULL);
+  i=rand()%strlen(numbers);
+  sprintf(lettersItem, "%c", numbers[i]);
+  if(item_find_by_title(lettersItem)!=NULL)
+    {
+      g_free(lettersItem);
+      return NULL;
+    }
 
   str = g_strdup_printf("gcompris/dice/gnome-dice%c.png", numbers[i]);
 
