@@ -1,6 +1,6 @@
 /* gcompris - gcompris.h
  *
- * Time-stamp: <2001/05/09 00:19:44 bruno>
+ * Time-stamp: <2001/08/28 02:00:07 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -42,7 +42,7 @@
 
 #define BOARDWIDTH  800
 #define BOARDHEIGHT 600
-#define BARHEIGHT   100
+#define BARHEIGHT   80
 
 
 /*****************************************************************************/
@@ -59,6 +59,21 @@ void		 gcompris_bar_set_timer (guint time);
 void		 gcompris_bar_set_maxtimer (guint time);
 void		 gcompris_bar_set_message (const gchar *message);
 
+/* Status bar control */
+typedef enum
+{
+  GCOMPRIS_BAR_LEVEL	= 1 << 0,
+  GCOMPRIS_BAR_OK	= 1 << 1,
+  GCOMPRIS_BAR_HELP	= 1 << 2,
+} GComprisBarFlags;
+
+void		 gcompris_bar_set (const GComprisBarFlags flags);
+
+/* Help window */
+void		 gcompris_help_start (gchar *title, gchar *content);
+
+/* General */
+GnomeCanvasGroup *gcompris_get_canvas();
 
 #endif
 
